%global _hardened_build 1
%define mediadir /var/lib/gmediaserver
Name:           gmediaserver
Version:        0.13.0
Release:        17%{?dist}
Summary:        UPnP compatible media server for the GNU system

Group:          Applications/Multimedia
License:        GPLv2+
URL:            http://www.gnu.org/software/gmediaserver/
Source0:        http://download.savannah.gnu.org/releases/gmediaserver/%{name}-%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.conf
Source3:        %{name}.logrotate
Source4:        %{name}.service
Patch0:         %{name}-infofix.patch
Patch1:         %{name}-%{version}-compilefix.patch
Patch2:         %{name}-aarch64.patch

BuildRequires:  libupnp-devel gettext taglib-devel flex byacc id3lib-devel e2fsprogs-devel pkgconfig
BuildRequires:  file-devel
BuildRequires:  systemd-units
Requires(post): /sbin/install-info /sbin/chkconfig
Requires(preun): /sbin/install-info /sbin/chkconfig
Requires: logrotate
Requires(pre): shadow-utils
Requires(postun): shadow-utils
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Requires(post): systemd-sysv

%description
GMediaServer is a UPnP compatible media server for the GNU system. It is part
of the GNU project.

GMediaServer serves audio and video files to certain network connected media
players. Most hardware media players only play music and/or video - they don't
provide the media themselves. Those media files have to come from a device on
the network. 

%prep
%setup -q
%patch0 -p0 -b .infofix
%patch1 -p1 -b .fix
%patch2 -p1 -b .aarch64

%build
%configure  --disable-rpath --disable-static
make %{?_smp_mflags}
iconv -f ISO88591 -t UTF8 AUTHORS > AUTHORSfixed
iconv -f ISO88591 -t UTF8 NEWS > NEWSfixed
mv -f AUTHORSfixed AUTHORS
mv -f NEWSfixed NEWS

%install
mkdir -p $RPM_BUILD_ROOT%{mediadir}
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log/%{name}
touch $RPM_BUILD_ROOT%{_localstatedir}/log/%{name}/%{name}.log

install -D -m755 -p %{SOURCE1} $RPM_BUILD_ROOT%{_initrddir}/%{name}

install -D -m644 -p %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}

install -D -m644 -p %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/%{name}

install -D -m644 -p %{SOURCE4} $RPM_BUILD_ROOT%{_unitdir}/%{name}.service

make install DESTDIR=$RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_sbindir}
mv $RPM_BUILD_ROOT%{_bindir}/%{name} $RPM_BUILD_ROOT%{_sbindir}/%{name}

%find_lang %{name}
rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%triggerun -- %{name} < 0.13.0-10
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply gmediaserver
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save %{name} >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del %{name} >/dev/null 2>&1 || :
/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :


%post
/sbin/install-info %{_infodir}/%{name}.info.gz %{_infodir}/dir || :
if [ $1 -eq 1 ] ; then 
    # Initial installation 
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
useradd -r -g %{name} -d %{mediadir} -s /sbin/nologin \
	-c "gmediaserver daemon user" %{name}
exit 0

%preun
if [ $1 = 0 ]; then
    /sbin/install-info --delete %{_infodir}/%{name}.info.gz %{_infodir}/dir || :
    /bin/systemctl --no-reload disable %{name}.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}.service > /dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ "$1" -ge "1" ] ; then
[ `getent passwd %{name} | cut -d: -f6` !=  %{mediadir} ] && usermod -d %{mediadir} %{name}
/bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%files -f %{name}.lang
%doc AUTHORS COPYING NEWS README TODO
%{_sbindir}/%{name}
%{_infodir}/%{name}.info.gz
%{_mandir}/man1/%{name}.*
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config %{_unitdir}/%{name}.service
%{_initrddir}/%{name}
%attr(-,%{name},%{name}) %{_localstatedir}/log/%{name}
%ghost %{_localstatedir}/log/%{name}/%{name}.log
%attr(-,%{name},%{name}) %{mediadir}

%changelog
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Mar 30 2014 Karol Trzcionka <karlik at fedoraproject.org> - 0.13.0-15
- apply aarch64 patch (rhbz#925431)
- enable hardened build (rhbz#955280)
- fix -Werror=format-security build (rhbz#1037090)

* Mon Aug 05 2013 Karol Trzcionka <karlik at fedoraproject.org> - 0.13.0-14
- Fix compile patch (compatibility with upnp header)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Mar 13 2012 Karol Trzcionka <karlik at fedoraproject.org> - 0.13.0-10
- Add native systemd service

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Oct 26 2011 Tom Callaway <spot@fedoraproject.org> - 0.13.0-8
- rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jun 26 2008 Karol Trzcionka <karlikt at gmail.com> - 0.13.0-4
- Change mediadir
- Fix initscript according to guidelines
- Add condrestart in %%postun
- Some changes in %%pre section
* Sat Feb 09 2008 Karol Trzcionka <karlikt at gmail.com> - 0.13.0-3
- respin (gcc43)
* Mon Nov 19 2007 Karol Trzcionka <karlikt at gmail.com> - 0.13.0-2
- Rebuild with new libupnp (v1.6.1)
* Sun Nov 18 2007 Karol Trzcionka <karlikt at gmail.com> - 0.13.0-1
- Update to v0.13.0
* Mon Aug 27 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-11
- Rebuild for ppc32
* Tue Jun 26 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-10
- Change %%pre section and add requires(pre)
- Rebuild with new libupnp (v1.6.0)
* Mon May 07 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-9
- Rebuild with new libupnp version
* Sat Apr 28 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-8
- Fix init file
* Thu Apr 19 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-7
- Change BRs
- Fix init-file
* Mon Apr 02 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-6
- small specfile fixes
- delete %%postun section
* Mon Mar 26 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-5
- Fix mediadir in config-file and init
- default log-file in %%ghost
* Thu Mar 22 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-4
- Update requires
- Fix init-script and inconsistency in spec
* Tue Mar 20 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-3
- Add init-script
* Sun Jan 21 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-2
- Update buildrequires
- Fix install-info
* Mon Jan 08 2007 Karol Trzcionka <karlikt at gmail.com> - 0.12.0-1
- Initial Release
